@@ -408,7 +408,7 @@ widgets.devalued <- function(
       rhs <- rlang::f_rhs(this)
       x <- mutate(x, !!lhs := ifelse(`_tablet_level` != 'numeric', NA, rlang::eval_tidy(rhs)))
    }
-   x <- gather(x, key = '_tablet_stat', value = '_tablet_widget', !!!keep)
+   x <- gather(x, key = '_tablet_stat', value = '_tablet_widget', !!!keep, factor_key = TRUE)
    x <- filter(x, !is.na(`_tablet_widget`))
    x <- arrange(x, .by_group = TRUE)
    x <- select(x,!!!groups(x), `_tablet_N`:`_tablet_level`, `_tablet_stat`, `_tablet_widget`)
@@ -445,7 +445,8 @@ groupless.data.frame <- function(x,...){
    # then execute
    grp <- groups(x)
    x <- ungroup(x)
-   x <- select(x, setdiff(names(x), grp))
+   #x <- select(x, setdiff(names(x), grp))
+   x <- select(x, setdiff(names(x), sapply(grp, rlang::as_string))) # very important when grp name contains spaces!
    x <- observations(x, ...)
    x <- devalued(x, ...)
    x <- widgets(x, ...)
@@ -589,7 +590,7 @@ tablet <- function(x, ...)UseMethod('tablet')
 #' Column attributes 'label' and 'title' (highest priority) are substituted for column name, if present.
 #' @param x groupwise
 #' @param ... ignored
-#' @param all a column name for ungrouped statistics
+#' @param all a column name for ungrouped statistics; can have length zero to suppress ungrouped column
 #' @param lab a list of formulas to generate column labels; \\n is translated as <br> in html context
 #' @importFrom dplyr groups ungroup select
 #' @importFrom tidyr spread
@@ -599,9 +600,9 @@ tablet <- function(x, ...)UseMethod('tablet')
 #' @return 'tablet', with columns for each combination of groups, and:
 #' \item{_tablet_name}{observation identifier}
 #' \item{_tablet_level}{factor level (or special value 'numeric' for numerics)}
+#' \item{_tablet_sort}{sorting column}
 #' \item{_tablet_stat}{the LHS of formulas in 'fac' and 'num'}
 #' \item{All (or value of 'all' argument)}{ungrouped results}
-#' \item{_tablet_sort}{sorting column}
 tablet.groupwise <- function(
    x,
    ...,
@@ -613,7 +614,10 @@ tablet.groupwise <- function(
 
   # convert certain columns to attributes
   myclass <- class(x)
-  stopifnot(is.character(all), length(all) == 1)
+  stopifnot(
+     (length(all) == 0 ) |   # can be NULL or character(0)
+     (is.character(all) & length(all) == 1) # otherwise atomic char
+  )
   N <- unique(x$`_tablet_N`)
   if(!length(N))N <- 0L
   x$`_tablet_N` <- NULL
@@ -646,10 +650,13 @@ tablet.groupwise <- function(
      `_tablet_groupless`
   )
   tot <- unique(tot)
-  names(tot)[names(tot)=='_tablet_groupless'] <- all
+  if(length(all)){
+     names(tot)[names(tot)=='_tablet_groupless'] <- all
+  } else {
+       tot$`_tablet_groupless` <- NULL
+  }
 
   x <- ungroup(x)
-  x$`_tablet_groupless` <- NULL
 
   # distribute columns
   if(length(strata)){
@@ -680,7 +687,7 @@ tablet.groupwise <- function(
 
   # bind ungrouped stats
   suppressMessages(x <- left_join(x,tot))
-  attr(x[[all]], 'n') <- N
+  if(length(all))attr(x[[all]], 'n') <- N
   for(i in seq_len(ncol(x))){
      cl <- names(x)[[i]]
      if(grepl('_tablet_strata_', cl)){
@@ -740,6 +747,19 @@ tablet.groupwise <- function(
   x$`_tablet_level` <- as.character(x$`_tablet_level`)
   x$`_tablet_level` <- sub('.*_tablet_', '', x$`_tablet_level`)
 
+  constitutive <- c(
+     '_tablet_name',
+     '_tablet_level',
+     '_tablet_sort',
+     '_tablet_stat'
+  )
+
+  x <- cbind(
+    x[, constitutive, drop = FALSE],
+    x[,!(names(x) %in% constitutive), drop = FALSE]
+  )
+
+
   # this is the only constructor for 'tablet'
   class(x) <- union('tablet', setdiff(class(x), 'groupwise'))
   x
@@ -1007,7 +1027,7 @@ as_kable.tablet <- function(
 #' \code{x} (the numeric observations, or 1 for each factor value).
 #' Aggregate statistics generated by 'fun' are available
 #' for use in 'fac' and 'num'
-#' which create visualizations thereof. Column-specific
+#' which create visualizations thereof ('widgets'). Column-specific
 #' attributes are available to elements of 'lab', including
 #' the special attribute \code{name} (the current column name).
 #' For 'lab' only, if the RHS succeeds, it becomes the label
@@ -1061,7 +1081,7 @@ as_kable.tablet <- function(
 #' @param x data.frame (possibly grouped)
 #' @param ... substitute formulas for elements of fun, fac, num, lab
 #' @param na.rm whether to remove NA in general
-#' @param all a column name for ungrouped statistics
+#' @param all a column name for ungrouped statistics; can have length zero to suppress ungrouped column
 #' @param fun default aggregate functions expressed as formulas
 #' @param fac a list of formulas to generate widgets for factors
 #' @param num a list of formulas to generate widgets for numerics
@@ -1134,3 +1154,70 @@ tablet.data.frame <- function(
    y <- tablet(y, ..., all = all, lab = lab ) # tablet.groupwise
    y
 }
+
+#' Splice Some Things Together
+#'
+#' Spices some things together. Generic, with tablet-oriented method \code{\link{splice.data.frame}}.
+#'
+#' @param x object
+#' @param ... passed arguments
+#' @export
+#' @return see methods
+#' @keywords internal
+#' @examples
+#' example(splice.data.frame)
+splice <- function(x, ...)UseMethod('splice')
+
+#' Splice A Data Frame
+#'
+#' Splices a data.frame.  If the data.frame has groups, tablet() is
+#' called for each group in succession, only the last of which requests
+#' 'all'.  The results are column-bound, and duplicate columns
+#' are removed.
+#' @param x data.frame
+#' @param all a column name for ungrouped statistics; can have length zero to suppress ungrouped column
+#' @param ... passed to \code{\link{tablet}}
+#' @return tablet
+#' @export
+#' @keywords internal
+#' @examples
+#' library(boot)
+#' library(dplyr)
+#' library(magrittr)
+#' melanoma %>%
+#'   select(-time, -year) %>%
+#'   mutate(sex = factor(sex), ulcer = factor(ulcer)) %>%
+#'   mutate(status2 = ifelse(status == 2, 2, 4)) %>%
+#'   group_by(status, status2) %>%
+#'   splice
+splice.data.frame <- function(x, all = 'All', ...){
+   grp <- groups(x)
+   if(!length(grp))return(tablet(x, ...))
+   x <- ungroup(x)
+   part <- list()
+   for(g in seq_along(grp)){
+      group <- grp[[g]]
+      this <- group_by(x, !!group)
+      for(i in setdiff(grp, list(group))) this[[i]] <- NULL
+      tot <- all
+      if(g < length(grp)) tot <- character(0) # 'all' only for last table
+      that <- tablet(this, all = tot, ...)
+      part[[group]] <- that
+   }
+   names(part) <- NULL
+   out <- do.call(cbind, part)
+
+   # remove dup columns
+   dupcol <- rep(FALSE, ncol(out))
+   if(ncol(out))
+   for(i in seq_along(out)[-1]){
+      for( j in 1:(i-1)){
+         if(identical(out[[i]], out[[j]])){
+            dupcol[[i]] <- TRUE
+         }
+      }
+   }
+   out <- out[,!dupcol, drop = FALSE]
+   class(out) <- class(part[[1]])
+   out
+}
